@@ -7,13 +7,18 @@
  * Copyright  2003 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms specified in the COPYING file
  * distributed with the Net-SNMP package.
+ *
+ * Portions of this file are copyrighted by:
+ * Copyright (c) 2016 VMware, Inc. All rights reserved.
+ * Use is subject to license terms specified in the COPYING file
+ * distributed with the Net-SNMP package.
  */
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-features.h>
 
 #include <sys/types.h>
 
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #endif
 
@@ -22,9 +27,9 @@
 
 #include <net-snmp/agent/bulk_to_next.h>
 
-netsnmp_feature_child_of(agent_handler, libnetsnmpagent)
+netsnmp_feature_child_of(agent_handler, libnetsnmpagent);
 
-netsnmp_feature_child_of(handler_mark_requests_as_delegated, agent_handler)
+netsnmp_feature_child_of(handler_mark_requests_as_delegated, agent_handler);
 
 static netsnmp_mib_handler *_clone_handler(netsnmp_mib_handler *it);
 
@@ -293,8 +298,16 @@ netsnmp_register_handler(netsnmp_handler_registration *reginfo)
      * for handlers that can't GETBULK, force a conversion handler on them 
      */
     if (!(reginfo->modes & HANDLER_CAN_GETBULK)) {
-        netsnmp_inject_handler(reginfo,
-                               netsnmp_get_bulk_to_next_handler());
+        handler = netsnmp_get_bulk_to_next_handler();
+        if (!handler ||
+            (netsnmp_inject_handler(reginfo, handler) != SNMPERR_SUCCESS)) {
+            snmp_log(LOG_WARNING, "could not inject bulk to next handler\n");
+            if (handler)
+                netsnmp_handler_free(handler);
+            /** should this be a critical error? */
+            netsnmp_handler_registration_free(reginfo);
+            return SNMP_ERR_GENERR;
+        }
     }
 
     for (handler = reginfo->handler; handler; handler = handler->next) {
@@ -327,6 +340,8 @@ netsnmp_register_handler(netsnmp_handler_registration *reginfo)
 int
 netsnmp_unregister_handler(netsnmp_handler_registration *reginfo)
 {
+    if (!reginfo)
+        return SNMPERR_SUCCESS;
     return unregister_mib_context(reginfo->rootoid, reginfo->rootoid_len,
                                   reginfo->priority,
                                   reginfo->range_subid, reginfo->range_ubound,
@@ -439,8 +454,13 @@ netsnmp_inject_handler_before(netsnmp_handler_registration *reginfo,
             if (strcmp(nexth->handler_name, before_what) == 0)
                 break;
         }
-        if (!nexth)
+        if (!nexth) {
+	    snmp_log(LOG_ERR, "Cannot inject '%s' before '%s': not found\n", handler->handler_name, before_what);
+	    snmp_log(LOG_ERR, "The handlers are:\n");
+	    for (nexth = reginfo->handler; nexth; nexth = nexth->next)
+		snmp_log(LOG_ERR, "  %s\n", nexth->handler_name);
             return SNMP_ERR_GENERR;
+	}
         if (prevh) {
             /* after prevh and before nexth */
             prevh->next = handler;
@@ -647,7 +667,7 @@ netsnmp_call_next_handler(netsnmp_mib_handler *current,
  *
  *  @return Returns SNMPERR_SUCCESS or SNMP_ERR_* error code.
  */
-netsnmp_feature_child_of(netsnmp_call_next_handler_one_request,netsnmp_unused)
+netsnmp_feature_child_of(netsnmp_call_next_handler_one_request,netsnmp_unused);
 #ifndef NETSNMP_FEATURE_REMOVE_NETSNMP_CALL_NEXT_HANDLER_ONE_REQUEST
 NETSNMP_INLINE int
 netsnmp_call_next_handler_one_request(netsnmp_mib_handler *current,
@@ -786,56 +806,51 @@ netsnmp_handler_registration_dup(netsnmp_handler_registration *reginfo)
 {
     netsnmp_handler_registration *r = NULL;
 
-    if (reginfo == NULL) {
+    if (reginfo == NULL)
         return NULL;
-    }
 
-
-    r = (netsnmp_handler_registration *) calloc(1,
-                                                sizeof
-                                                (netsnmp_handler_registration));
-
-    if (r != NULL) {
-        r->modes = reginfo->modes;
-        r->priority = reginfo->priority;
-        r->range_subid = reginfo->range_subid;
-        r->timeout = reginfo->timeout;
-        r->range_ubound = reginfo->range_ubound;
-        r->rootoid_len = reginfo->rootoid_len;
-
-        if (reginfo->handlerName != NULL) {
-            r->handlerName = strdup(reginfo->handlerName);
-            if (r->handlerName == NULL) {
-                netsnmp_handler_registration_free(r);
-                return NULL;
-            }
-        }
-
-        if (reginfo->contextName != NULL) {
-            r->contextName = strdup(reginfo->contextName);
-            if (r->contextName == NULL) {
-                netsnmp_handler_registration_free(r);
-                return NULL;
-            }
-        }
-
-        if (reginfo->rootoid != NULL) {
-            r->rootoid =
-                snmp_duplicate_objid(reginfo->rootoid, reginfo->rootoid_len);
-            if (r->rootoid == NULL) {
-                netsnmp_handler_registration_free(r);
-                return NULL;
-            }
-        }
-
-        r->handler = netsnmp_handler_dup(reginfo->handler);
-        if (r->handler == NULL) {
-            netsnmp_handler_registration_free(r);
-            return NULL;
-        }
+    r = calloc(1, sizeof(netsnmp_handler_registration));
+    if (!r)
         return r;
+    r->modes = reginfo->modes;
+    r->priority = reginfo->priority;
+    r->range_subid = reginfo->range_subid;
+    r->timeout = reginfo->timeout;
+    r->range_ubound = reginfo->range_ubound;
+    r->rootoid_len = reginfo->rootoid_len;
+
+    if (reginfo->handlerName != NULL) {
+        r->handlerName = strdup(reginfo->handlerName);
+        if (r->handlerName == NULL)
+            goto err;
     }
 
+    if (reginfo->contextName != NULL) {
+        r->contextName = strdup(reginfo->contextName);
+        if (r->contextName == NULL)
+            goto err;
+    }
+
+    if (reginfo->rootoid != NULL) {
+        /*
+         * + 1 to make the following code safe:
+         * reginfo->rootoid[reginfo->rootoid_len++] = 0;
+         * See also netsnmp_scalar_helper_handler().
+         */
+        r->rootoid = malloc((reginfo->rootoid_len + 1) * sizeof(oid));
+        if (r->rootoid == NULL)
+            goto err;
+        memcpy(r->rootoid, reginfo->rootoid,
+               reginfo->rootoid_len * sizeof(oid));
+    }
+
+    r->handler = netsnmp_handler_dup(reginfo->handler);
+    if (r->handler == NULL)
+        goto err;
+    return r;
+
+err:
+    netsnmp_handler_registration_free(r);
     return NULL;
 }
 
@@ -1183,7 +1198,7 @@ netsnmp_inject_handler_into_subtree(netsnmp_subtree *tp, const char *name,
                         tptr->label_a, tptr->reginfo->handlerName));
             netsnmp_inject_handler_before(tptr->reginfo, _clone_handler(handler),
                                           before_what);
-        } else {
+        } else if (tptr->reginfo != NULL) {
             for (mh = tptr->reginfo->handler; mh != NULL; mh = mh->next) {
                 if (mh->handler_name && strcmp(mh->handler_name, name) == 0) {
                     DEBUGMSGTL(("injectHandler", "injecting handler into %s\n",
