@@ -1,3 +1,13 @@
+/*
+ * Portions of this file are subject to the following copyright(s).  See
+ * the Net-SNMP's COPYING file for more details and other copyrights
+ * that may apply:
+ *
+ * Portions of this file are copyrighted by:
+ * Copyright (c) 2016 VMware, Inc. All rights reserved.
+ * Use is subject to license terms specified in the COPYING file
+ * distributed with the Net-SNMP package.
+ */
 #include <net-snmp/net-snmp-config.h>
 
 #include <net-snmp/net-snmp-includes.h>
@@ -5,7 +15,7 @@
 
 #include <net-snmp/agent/old_api.h>
 
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
@@ -15,6 +25,17 @@
 
 #include <stddef.h>
 
+/*
+ * mib clients are passed a pointer to a oid buffer.  Some mib clients
+ * * (namely, those first noticed in mibII/vacm.c) modify this oid buffer
+ * * before they determine if they really need to send results back out
+ * * using it.  If the master agent determined that the client was not the
+ * * right one to talk with, it will use the same oid buffer to pass to the
+ * * rest of the clients, which may not longer be valid.  This should be
+ * * fixed in all clients rather than the master.  However, its not a
+ * * particularily easy bug to track down so this saves debugging time at
+ * * the expense of a few memcpy's.
+ */
 #define MIB_CLIENTS_ARE_EVIL 1
 
 #ifdef HAVE_DMALLOC_H
@@ -30,7 +51,6 @@ static void free_wrapper(void * p)
  * don't use these! 
  */
 void            set_current_agent_session(netsnmp_agent_session *asp);
-netsnmp_agent_session *netsnmp_get_current_agent_session(void);
 
 /** @defgroup old_api old_api
  *  Calls mib module code written in the old style of code.
@@ -51,6 +71,12 @@ get_old_api_handler(void)
     return netsnmp_create_handler("old_api", netsnmp_old_api_helper);
 }
 
+static void *
+netsnmp_clone_variable(void *p)
+{
+    return netsnmp_duplicate_variable(p);
+}
+
 struct variable *
 netsnmp_duplicate_variable(const struct variable *var)
 {
@@ -84,6 +110,7 @@ netsnmp_register_old_api(const char *moduleName,
 {
 
     unsigned int    i;
+    int             res;
 
     /*
      * register all subtree nodes 
@@ -98,14 +125,22 @@ netsnmp_register_old_api(const char *moduleName,
 	vp = netsnmp_duplicate_variable((const struct variable *)
 					((const char *) var + varsize * i));
 
+        if (vp == NULL) {
+            SNMP_FREE(reginfo);
+            return SNMP_ERR_GENERR;
+        }
+
         reginfo->handler = get_old_api_handler();
         reginfo->handlerName = strdup(moduleName);
         reginfo->rootoid_len = (mibloclen + vp->namelen);
         reginfo->rootoid =
             (oid *) malloc(reginfo->rootoid_len * sizeof(oid));
-        if (reginfo->rootoid == NULL) {
+        if (NULL == reginfo->handler || NULL == reginfo->handlerName ||
+            NULL == reginfo->rootoid) {
+            netsnmp_handler_free(reginfo->handler);
             SNMP_FREE(vp);
             SNMP_FREE(reginfo->handlerName);
+            SNMP_FREE(reginfo->rootoid);
             SNMP_FREE(reginfo);
             return SNMP_ERR_GENERR;
         }
@@ -114,8 +149,7 @@ netsnmp_register_old_api(const char *moduleName,
         memcpy(reginfo->rootoid + mibloclen, vp->name, vp->namelen
                * sizeof(oid));
         reginfo->handler->myvoid = (void *) vp;
-        reginfo->handler->data_clone
-	    = (void *(*)(void *))netsnmp_duplicate_variable;
+        reginfo->handler->data_clone = netsnmp_clone_variable;
         reginfo->handler->data_free = free;
 
         reginfo->priority = priority;
@@ -130,9 +164,11 @@ netsnmp_register_old_api(const char *moduleName,
         /*
          * register ourselves in the mib tree 
          */
-        if (netsnmp_register_handler(reginfo) != MIB_REGISTERED_OK) {
-            /** netsnmp_handler_registration_free(reginfo); already freed */
-            /* SNMP_FREE(vp); already freed */
+        res = netsnmp_register_handler(reginfo);
+        if (MIB_REGISTERED_OK != res) {
+            /** reginfo already freed on error. */
+            snmp_log(LOG_WARNING, "old_api handler registration failed\n");
+            return res;
         }
     }
     return SNMPERR_SUCCESS;
@@ -168,23 +204,17 @@ netsnmp_register_mib_table_row(const char *moduleName,
              * Unregister whatever we have registered so far, and
              * return an error.  
              */
+            snmp_log(LOG_ERR, "mib table row registration failed\n");
             rc = MIB_REGISTRATION_FAILED;
             break;
         }
-        memset(r, 0, sizeof(netsnmp_handler_registration));
 
         r->handler = get_old_api_handler();
         r->handlerName = strdup(moduleName);
-
-        if (r->handlerName == NULL) {
-            netsnmp_handler_registration_free(r);
-            break;
-        }
-
         r->rootoid_len = mibloclen;
         r->rootoid = (oid *) malloc(r->rootoid_len * sizeof(oid));
-
-        if (r->rootoid == NULL) {
+        if (r->handler == NULL || r->handlerName == NULL ||
+            r->rootoid == NULL) {
             netsnmp_handler_registration_free(r);
             rc = MIB_REGISTRATION_FAILED;
             break;
@@ -198,18 +228,12 @@ netsnmp_register_mib_table_row(const char *moduleName,
         DEBUGMSG(("netsnmp_register_mib_table_row", "(%d)\n",
                      (var_subid - vr->namelen)));
         r->handler->myvoid = netsnmp_duplicate_variable(vr);
-        r->handler->data_clone = (void *(*)(void *))netsnmp_duplicate_variable;
+        r->handler->data_clone = netsnmp_clone_variable;
         r->handler->data_free = free;
 
-        if (r->handler->myvoid == NULL) {
-            netsnmp_handler_registration_free(r);
-            rc = MIB_REGISTRATION_FAILED;
-            break;
-        }
-
         r->contextName = (context) ? strdup(context) : NULL;
-
-        if (context != NULL && r->contextName == NULL) {
+        if (r->handler->myvoid == NULL ||
+            (context != NULL && r->contextName == NULL)) {
             netsnmp_handler_registration_free(r);
             rc = MIB_REGISTRATION_FAILED;
             break;
@@ -227,9 +251,10 @@ netsnmp_register_mib_table_row(const char *moduleName,
         if ((rc =
              netsnmp_register_handler_nocallback(r)) !=
             MIB_REGISTERED_OK) {
+            snmp_log(LOG_ERR, "mib table row registration failed\n");
             DEBUGMSGTL(("netsnmp_register_mib_table_row",
                         "register failed %d\n", rc));
-            netsnmp_handler_registration_free(r);
+            /** reginfo already freed */
             break;
         }
 
@@ -266,7 +291,7 @@ netsnmp_old_api_helper(netsnmp_mib_handler *handler,
                        netsnmp_request_info *requests)
 {
 
-#if MIB_CLIENTS_ARE_EVIL
+#ifdef MIB_CLIENTS_ARE_EVIL
     oid             save[MAX_OID_LEN];
     size_t          savelen = 0;
 #endif
@@ -274,7 +299,7 @@ netsnmp_old_api_helper(netsnmp_mib_handler *handler,
     int             exact = 1;
     int             status;
 
-    struct variable *vp;
+    struct variable *const vp = handler->myvoid;
     netsnmp_old_api_cache *cacheptr;
     netsnmp_agent_session *oldasp = NULL;
     u_char         *access = NULL;
@@ -283,8 +308,6 @@ netsnmp_old_api_helper(netsnmp_mib_handler *handler,
     size_t          tmp_len;
     oid             tmp_name[MAX_OID_LEN];
 
-    vp = (struct variable *) handler->myvoid;
-
     /*
      * create old variable structure with right information 
      */
@@ -304,7 +327,7 @@ netsnmp_old_api_helper(netsnmp_mib_handler *handler,
 
     for (; requests; requests = requests->next) {
 
-#if MIB_CLIENTS_ARE_EVIL
+#ifdef MIB_CLIENTS_ARE_EVIL
         savelen = requests->requestvb->name_length;
         memcpy(save, requests->requestvb->name, savelen * sizeof(oid));
 #endif
@@ -318,9 +341,12 @@ netsnmp_old_api_helper(netsnmp_mib_handler *handler,
             /*
              * Actually call the old mib-module function 
              */
-            if (vp && vp->findVar) {
-                memcpy(tmp_name, requests->requestvb->name,
-                                 requests->requestvb->name_length*sizeof(oid));
+            if (vp->findVar) {
+                tmp_len = requests->requestvb->name_length*sizeof(oid);
+                memcpy(tmp_name, requests->requestvb->name, tmp_len);
+                /** clear the rest of tmp_name to keep valgrind happy */
+                memset(&tmp_name[requests->requestvb->name_length], 0x0,
+                       sizeof(tmp_name)-tmp_len);
                 tmp_len = requests->requestvb->name_length;
                 access = (*(vp->findVar)) (cvp, tmp_name, &tmp_len,
                                            exact, &len, &write_method);
@@ -354,7 +380,7 @@ netsnmp_old_api_helper(netsnmp_mib_handler *handler,
                 /*
                  * no result returned 
                  */
-#if MIB_CLIENTS_ARE_EVIL
+#ifdef MIB_CLIENTS_ARE_EVIL
                 if (access == NULL) {
                     if (netsnmp_oid_equals(requests->requestvb->name,
                                          requests->requestvb->name_length,
@@ -391,6 +417,7 @@ netsnmp_old_api_helper(netsnmp_mib_handler *handler,
             /*
              * BBB: fall through for everything that is a set (see AAA) 
              */
+	    /* FALL THROUGH */
 
         default:
             /*
