@@ -1,3 +1,14 @@
+/*
+ * Portions of this file are subject to the following copyright(s).  See
+ * the Net-SNMP's COPYING file for more details and other copyrights
+ * that may apply:
+ *
+ * Portions of this file are copyrighted by:
+ * Copyright (c) 2016 VMware, Inc. All rights reserved.
+ * Use is subject to license terms specified in the COPYING file
+ * distributed with the Net-SNMP package.
+ */
+
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-features.h>
 
@@ -20,18 +31,18 @@ static void free_wrapper(void * p)
 #define free_wrapper free
 #endif
 
-netsnmp_feature_provide(watcher_all)
-netsnmp_feature_child_of(watcher_all, mib_helpers)
-netsnmp_feature_child_of(watcher_create_info6, watcher_all)
-netsnmp_feature_child_of(watcher_register_timestamp, watcher_all)
-netsnmp_feature_child_of(watcher_ulong_scalar, watcher_all)
-netsnmp_feature_child_of(watcher_read_only_ulong_scalar, watcher_all)
-netsnmp_feature_child_of(watcher_read_only_int_scalar, watcher_all)
-netsnmp_feature_child_of(watcher_long_scalar, watcher_all)
-netsnmp_feature_child_of(watcher_read_only_long_scalar, watcher_all)
-netsnmp_feature_child_of(watcher_int_scalar, watcher_all)
-netsnmp_feature_child_of(read_only_counter32_scalar, watcher_all)
-netsnmp_feature_child_of(watcher_spinlock, watcher_all)
+netsnmp_feature_provide(watcher_all);
+netsnmp_feature_child_of(watcher_all, mib_helpers);
+netsnmp_feature_child_of(watcher_create_info6, watcher_all);
+netsnmp_feature_child_of(watcher_register_timestamp, watcher_all);
+netsnmp_feature_child_of(watcher_ulong_scalar, watcher_all);
+netsnmp_feature_child_of(watcher_read_only_ulong_scalar, watcher_all);
+netsnmp_feature_child_of(watcher_read_only_int_scalar, watcher_all);
+netsnmp_feature_child_of(watcher_long_scalar, watcher_all);
+netsnmp_feature_child_of(watcher_read_only_long_scalar, watcher_all);
+netsnmp_feature_child_of(watcher_int_scalar, watcher_all);
+netsnmp_feature_child_of(read_only_counter32_scalar, watcher_all);
+netsnmp_feature_child_of(watcher_spinlock, watcher_all);
 
 /** @defgroup watcher watcher
  *  Watch a specified variable and process it as an instance or scalar object
@@ -107,13 +118,22 @@ int
 netsnmp_register_watched_instance(netsnmp_handler_registration *reginfo,
                                   netsnmp_watcher_info         *watchinfo)
 {
-    netsnmp_mib_handler *whandler;
+    netsnmp_mib_handler *whandler = NULL;
 
-    whandler         = netsnmp_get_watcher_handler();
-    whandler->myvoid = (void *)watchinfo;
+    if (reginfo && watchinfo) {
+        whandler = netsnmp_get_watcher_handler();
+        if (whandler) {
+            whandler->myvoid = (void *)watchinfo;
+            if (netsnmp_inject_handler(reginfo, whandler) == SNMPERR_SUCCESS)
+                return netsnmp_register_instance(reginfo);
+        }
+    }
 
-    netsnmp_inject_handler(reginfo, whandler);
-    return netsnmp_register_instance(reginfo);
+    snmp_log(LOG_ERR, "could not create watched instance handler\n");
+    netsnmp_handler_free(whandler);
+    netsnmp_handler_registration_free(reginfo);
+
+    return MIB_REGISTRATION_FAILED;
 }
 
 /**
@@ -125,14 +145,23 @@ int
 netsnmp_register_watched_instance2(netsnmp_handler_registration *reginfo,
 				   netsnmp_watcher_info         *watchinfo)
 {
-    netsnmp_mib_handler *whandler;
+    netsnmp_mib_handler *whandler = NULL;
 
-    whandler         = netsnmp_get_watcher_handler();
-    whandler->myvoid = (void *)watchinfo;
-    netsnmp_owns_watcher_info(whandler);
+    if (reginfo && watchinfo) {
+        whandler = netsnmp_get_watcher_handler();
+        if (whandler) {
+            whandler->myvoid = (void *)watchinfo;
+            netsnmp_owns_watcher_info(whandler);
+            if (netsnmp_inject_handler(reginfo, whandler) == SNMPERR_SUCCESS)
+                return netsnmp_register_instance(reginfo);
+        }
+    }
 
-    netsnmp_inject_handler(reginfo, whandler);
-    return netsnmp_register_instance(reginfo);
+    snmp_log(LOG_ERR, "could not create watched instance2 handler\n");
+    netsnmp_handler_free(whandler);
+    netsnmp_handler_registration_free(reginfo);
+
+    return MIB_REGISTRATION_FAILED;
 }
 
 /**
@@ -144,13 +173,22 @@ int
 netsnmp_register_watched_scalar(netsnmp_handler_registration *reginfo,
                                   netsnmp_watcher_info         *watchinfo)
 {
-    netsnmp_mib_handler *whandler;
+    netsnmp_mib_handler *whandler = NULL;
 
-    whandler         = netsnmp_get_watcher_handler();
-    whandler->myvoid = (void *)watchinfo;
+    if (reginfo && watchinfo) {
+        whandler = netsnmp_get_watcher_handler();
+        if (whandler) {
+            whandler->myvoid = (void *)watchinfo;
+            if (netsnmp_inject_handler(reginfo, whandler) == SNMPERR_SUCCESS)
+                return netsnmp_register_scalar(reginfo);
+        }
+    }
 
-    netsnmp_inject_handler(reginfo, whandler);
-    return netsnmp_register_scalar(reginfo);
+    snmp_log(LOG_ERR, "could not create watched scalar handler\n");
+    netsnmp_handler_free(whandler);
+    netsnmp_handler_registration_free(reginfo);
+
+    return MIB_REGISTRATION_FAILED;
 }
 
 /**
@@ -162,14 +200,23 @@ int
 netsnmp_register_watched_scalar2(netsnmp_handler_registration *reginfo,
                                   netsnmp_watcher_info         *watchinfo)
 {
-    netsnmp_mib_handler *whandler;
+    netsnmp_mib_handler *whandler = NULL;
 
-    whandler         = netsnmp_get_watcher_handler();
-    whandler->myvoid = (void *)watchinfo;
-    netsnmp_owns_watcher_info(whandler);
+    if (reginfo && watchinfo) {
+        whandler = netsnmp_get_watcher_handler();
+        if (whandler) {
+            whandler->myvoid = (void *)watchinfo;
+            netsnmp_owns_watcher_info(whandler);
+            if (netsnmp_inject_handler(reginfo, whandler) == SNMPERR_SUCCESS)
+                return netsnmp_register_scalar(reginfo);
+        }
+    }
 
-    netsnmp_inject_handler(reginfo, whandler);
-    return netsnmp_register_scalar(reginfo);
+    snmp_log(LOG_ERR, "could not create watched scalar2 handler\n");
+    netsnmp_handler_free(whandler);
+    netsnmp_handler_registration_free(reginfo);
+
+    return MIB_REGISTRATION_FAILED;
 }
 
 void
@@ -177,7 +224,7 @@ netsnmp_owns_watcher_info(netsnmp_mib_handler *handler)
 {
     netsnmp_assert(handler);
     netsnmp_assert(handler->myvoid);
-    handler->data_clone = (void *(*)(void *))netsnmp_clone_watcher_info;
+    handler->data_clone = netsnmp_clone_watcher_info;
     handler->data_free = free;
 }
 
@@ -242,7 +289,9 @@ netsnmp_watcher_helper_handler(netsnmp_mib_handler *handler,
                                netsnmp_request_info *requests)
 {
     netsnmp_watcher_info  *winfo = (netsnmp_watcher_info *) handler->myvoid;
+#ifndef NETSNMP_NO_WRITE_SUPPORT
     netsnmp_watcher_cache *old_data;
+#endif /* NETSNMP_NO_WRITE_SUPPORT */
 
     DEBUGMSGTL(("helper:watcher", "Got request:  %d\n", reqinfo->mode));
     DEBUGMSGTL(( "helper:watcher", "  oid:"));
@@ -359,9 +408,16 @@ netsnmp_watched_timestamp_register(netsnmp_mib_handler *whandler,
                                    netsnmp_handler_registration *reginfo,
                                    marker_t timestamp)
 {
-    whandler->myvoid = (void *)timestamp;
-    netsnmp_inject_handler(reginfo, whandler);
-    return netsnmp_register_scalar(reginfo);   /* XXX - or instance? */
+    if (reginfo && whandler && timestamp) {
+        whandler->myvoid = (void *)timestamp;
+        if (netsnmp_inject_handler(reginfo, whandler) == SNMPERR_SUCCESS)
+            return netsnmp_register_scalar(reginfo);   /* XXX - or instance? */
+    }
+
+    snmp_log(LOG_ERR, "could not create watched timestamp handler\n");
+    netsnmp_handler_registration_free(reginfo);
+
+    return MIB_REGISTRATION_FAILED;
 }
 
 #ifndef NETSNMP_FEATURE_REMOVE_WATCHER_REGISTER_TIMESTAMP
@@ -452,15 +508,28 @@ int
 netsnmp_register_watched_spinlock(netsnmp_handler_registration *reginfo,
                                    int *spinlock)
 {
-    netsnmp_mib_handler  *whandler;
-    netsnmp_watcher_info *winfo;
+    netsnmp_mib_handler  *whandler = NULL;
+    netsnmp_watcher_info *winfo = NULL;
 
-    whandler         = netsnmp_get_watched_spinlock_handler();
-    whandler->myvoid = (void *)spinlock;
-    winfo            = netsnmp_create_watcher_info((void *)spinlock,
-		           sizeof(int), ASN_INTEGER, WATCHER_FIXED_SIZE);
-    netsnmp_inject_handler(reginfo, whandler);
-    return netsnmp_register_watched_scalar2(reginfo, winfo);
+    if (reginfo && spinlock) {
+        whandler = netsnmp_get_watched_spinlock_handler();
+        if (whandler) {
+            whandler->myvoid = (void *)spinlock;
+            winfo = netsnmp_create_watcher_info((void *)spinlock, sizeof(int),
+                                                ASN_INTEGER,
+                                                WATCHER_FIXED_SIZE);
+            if (winfo &&
+                (netsnmp_inject_handler(reginfo, whandler) == SNMPERR_SUCCESS))
+                return netsnmp_register_watched_scalar2(reginfo, winfo);
+        }
+    }
+
+    snmp_log(LOG_ERR, "could not create watched spinlock handler\n");
+    SNMP_FREE(winfo);
+    netsnmp_handler_free(whandler);
+    netsnmp_handler_registration_free(reginfo);
+
+    return MIB_REGISTRATION_FAILED;
 }
 
 
@@ -470,8 +539,10 @@ netsnmp_watched_spinlock_handler(netsnmp_mib_handler *handler,
                                netsnmp_agent_request_info *reqinfo,
                                netsnmp_request_info *requests)
 {
+#ifndef NETSNMP_NO_WRITE_SUPPORT
     int     *spinlock = (int *) handler->myvoid;
     netsnmp_request_info *request;
+#endif /* NETSNMP_NO_WRITE_SUPPORT */
 
     DEBUGMSGTL(("helper:watcher:spinlock",
                                "Got request:  %d\n", reqinfo->mode));
@@ -520,10 +591,12 @@ netsnmp_watched_spinlock_handler(netsnmp_mib_handler *handler,
      *
      ***************************/
 
-netsnmp_watcher_info *
-netsnmp_clone_watcher_info(netsnmp_watcher_info *winfo)
+void *
+netsnmp_clone_watcher_info(void *p)
 {
+    netsnmp_watcher_info *winfo = p;
     netsnmp_watcher_info *copy = malloc(sizeof(*copy));
+
     if (copy)
 	*copy = *winfo;
     return copy;
@@ -537,26 +610,34 @@ register_scalar_watcher(const char* name,
 {
     netsnmp_handler_registration *reginfo = NULL;
     netsnmp_mib_handler *whandler = NULL;
-    netsnmp_watcher_info* watchinfo =
-        netsnmp_create_watcher_info(data, size, type, WATCHER_FIXED_SIZE);
-    if (watchinfo)
+    netsnmp_watcher_info* watchinfo;
+
+    if (!name || !reg_oid || !data)
+        return MIB_REGISTRATION_FAILED;
+
+    watchinfo = netsnmp_create_watcher_info(data, size, type,
+                                            WATCHER_FIXED_SIZE);
+    if (watchinfo) {
         whandler = netsnmp_get_watcher_handler();
-    if (watchinfo && whandler) {
-        whandler->myvoid = watchinfo;
-	netsnmp_owns_watcher_info(whandler);
-        reginfo =
-            netsnmp_create_handler_registration(
-                name, subhandler, reg_oid, reg_oid_len, mode);
+        if (whandler) {
+            whandler->myvoid = watchinfo;
+            netsnmp_owns_watcher_info(whandler);
+            reginfo =
+                netsnmp_create_handler_registration(name, subhandler,
+                                                    reg_oid, reg_oid_len,
+                                                    mode);
+            if (reginfo &&
+                (netsnmp_inject_handler(reginfo, whandler) == SNMPERR_SUCCESS))
+                return netsnmp_register_scalar(reginfo);
+        }
     }
-    if (watchinfo && whandler && reginfo) {
-        netsnmp_inject_handler(reginfo, whandler);
-        return netsnmp_register_scalar(reginfo);
-    }
-    if (whandler)
-        netsnmp_handler_free(whandler);
-    else if (watchinfo)
-        free(watchinfo);
-    return SNMP_ERR_RESOURCEUNAVAILABLE;
+
+    snmp_log(LOG_ERR, "failed to register scalar watcher\n");
+    netsnmp_handler_free(whandler);
+    SNMP_FREE(watchinfo);
+    netsnmp_handler_registration_free(reginfo);
+
+    return MIB_REGISTRATION_FAILED;
 }
 
 #ifndef NETSNMP_FEATURE_REMOVE_WATCHER_ULONG_SCALAR
