@@ -16,9 +16,6 @@ config_add_mib(NET-SNMP-PERIODIC-NOTIFY-MIB);
 
 void init_deliverByNotify(void);
 
-void parse_deliver_config(const char *, char *);
-void free_deliver_config(void);
-
 SNMPAlarmCallback deliver_execute;
 
 #define NETSNMP_DELIVER_NO_PERIOD_OID   0x01
@@ -27,8 +24,8 @@ SNMPAlarmCallback deliver_execute;
 /* implementation details */
 typedef struct deliver_by_notify_s {
    int     frequency;
-   int     last_run;
-   int     next_run;
+   time_t  last_run;
+   time_t  next_run;
    oid    *target;
    size_t  target_len;
    int     max_packet_size;
