@@ -14,16 +14,16 @@
 #include "disman/schedule/schedCore.h"
 #include "disman/schedule/schedTable.h"
 
-netsnmp_feature_require(iquery)
-netsnmp_feature_require(iquery_pdu_session)
-netsnmp_feature_require(table_tdata)
-netsnmp_feature_require(date_n_time)
-netsnmp_feature_require(check_vb_uint)
+netsnmp_feature_require(iquery);
+netsnmp_feature_require(iquery_pdu_session);
+netsnmp_feature_require(table_tdata);
+netsnmp_feature_require(date_n_time);
+netsnmp_feature_require(check_vb_uint);
 #ifndef NETSNMP_NO_WRITE_SUPPORT
-netsnmp_feature_require(check_vb_type_and_max_size)
-netsnmp_feature_require(check_vb_oid)
-netsnmp_feature_require(check_vb_truthvalue)
-netsnmp_feature_require(table_tdata_insert_row)
+netsnmp_feature_require(check_vb_type_and_max_size);
+netsnmp_feature_require(check_vb_oid);
+netsnmp_feature_require(check_vb_truthvalue);
+netsnmp_feature_require(table_tdata_insert_row);
 #endif /* NETSNMP_NO_WRITE_SUPPORT */
 
 static netsnmp_table_registration_info *table_info;
@@ -449,7 +449,7 @@ schedTable_handler(netsnmp_mib_handler *handler,
                 recalculate = 1;
                 break;
             case COLUMN_SCHEDWEEKDAY:
-                entry->schedWeekDay  = request->requestvb->val.string[0];
+                entry->schedWeekDay[0] = request->requestvb->val.string[0];
                 recalculate = 1;
                 break;
             case COLUMN_SCHEDMONTH:
