@@ -3,20 +3,20 @@
  */
 
 #include <net-snmp/net-snmp-config.h>
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
 #endif
 
-#if TIME_WITH_SYS_TIME
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# if HAVE_SYS_TIME_H
+# ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # else
 #  include <time.h>
@@ -25,6 +25,7 @@
 
 #include <net-snmp/net-snmp-includes.h>
 #include <net-snmp/agent/net-snmp-agent-includes.h>
+#include <net-snmp/library/tools.h>
 
 #include "util_funcs/header_generic.h"
 #include "ucdDemoPublic.h"
@@ -106,11 +107,11 @@ var_ucdDemoPublic(struct variable *vp,
     static char     string[MYMAX + 1], *cp;
     int             i;
 
-    *write_method = 0;          /* assume it isnt writable for the time being */
+    *write_method = NULL;       /* assume it isnt writable for the time being */
     *var_len = sizeof(long_ret);        /* assume an integer and change later if not */
 
     if (header_generic(vp, name, length, exact, var_len, write_method))
-        return 0;
+        return NULL;
 
     /*
      * this is where we do the value assignments for the mib results. 
@@ -145,7 +146,7 @@ var_ucdDemoPublic(struct variable *vp,
         DEBUGMSGTL(("snmpd", "unknown sub-id %d in var_ucdDemoPublic\n",
                     vp->magic));
     }
-    return 0;
+    return NULL;
 }
 
 int
@@ -187,6 +188,7 @@ write_ucdDemoResetKeys(int action,
                                           demopass);
                 }
             }
+            free(engineID);
             /*
              * reset the keys 
              */
@@ -213,16 +215,9 @@ write_ucdDemoPublicString(int action,
         return SNMP_ERR_WRONGLENGTH;
     }
     if (action == COMMIT) {
-        if (var_val_len != 0) {
-            strncpy((char*)publicString, (const char*)var_val, sizeof(publicString)-1);
-            /* some sanity checks */
-            if (strlen((const char*)var_val) > sizeof(publicString)-1 ||
-                strlen((const char*)var_val) != var_val_len)
-                publicString[sizeof(publicString)-1] = '\0';
-            else
-                publicString[var_val_len] = '\0';
-        } else
-            publicString[0] = '\0';
+        sprintf((char*) publicString, "%.*s",
+                (int) SNMP_MIN(sizeof(publicString) - 1, var_val_len),
+                (const char*) var_val);
     }
     return SNMP_ERR_NOERROR;
 }
