@@ -1,4 +1,4 @@
-config_require(hardware/cpu/cpu)
+config_require(hardware/cpu/cpu);
 void init_cpu_mach( void );
 
  	  	 
