@@ -6,7 +6,7 @@
 #define _MIBGROUP_IPADDR_H
 
 #if !defined(NETSNMP_ENABLE_MFD_REWRITES)
-config_require(mibII/ip)
+config_require(mibII/ip);
 #endif
 
      extern FindVarMethod var_ipAddrEntry;
