@@ -19,18 +19,18 @@
 
 #include <net-snmp/net-snmp-config.h>
 
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
 #endif
-#if HAVE_MALLOC_H
+#ifdef HAVE_MALLOC_H
 #include <malloc.h>
 #endif
 #include <ctype.h>
@@ -54,11 +54,11 @@
 #include "vacm_vars.h"
 #include "util_funcs/header_generic.h"
 
-#if TIME_WITH_SYS_TIME
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# if HAVE_SYS_TIME_H
+# ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # else
 #  include <time.h>
@@ -1174,14 +1174,15 @@ write_vacmAccessStatus(int action,
         free(newGroupName);
         free(newContextPrefix);
     } else if (action == ACTION) {
-        access_parse_oid(&name[ACCESS_MIB_LENGTH],
-                         name_len - ACCESS_MIB_LENGTH,
-                         (u_char **) & newGroupName, &groupNameLen,
-                         (u_char **) & newContextPrefix, &contextPrefixLen,
-                         &model, &level);
-        aptr =
-            vacm_getAccessEntry(newGroupName, newContextPrefix, model,
-                                level);
+        if (access_parse_oid(&name[ACCESS_MIB_LENGTH],
+                             name_len - ACCESS_MIB_LENGTH,
+                             (u_char **) & newGroupName, &groupNameLen,
+                             (u_char **) & newContextPrefix, &contextPrefixLen,
+                             &model, &level)) {
+            return SNMP_ERR_INCONSISTENTNAME;
+        }
+
+        aptr = vacm_getAccessEntry(newGroupName, newContextPrefix, model, level);
 
         if (aptr != NULL) {
             if (long_ret == RS_CREATEANDGO || long_ret == RS_ACTIVE) {
@@ -1201,14 +1202,15 @@ write_vacmAccessStatus(int action,
         free(newGroupName);
         free(newContextPrefix);
     } else if (action == COMMIT) {
-        access_parse_oid(&name[ACCESS_MIB_LENGTH],
-                         name_len - ACCESS_MIB_LENGTH,
-                         (u_char **) & newGroupName, &groupNameLen,
-                         (u_char **) & newContextPrefix, &contextPrefixLen,
-                         &model, &level);
-        aptr =
-            vacm_getAccessEntry(newGroupName, newContextPrefix, model,
-                                level);
+        if (access_parse_oid(&name[ACCESS_MIB_LENGTH],
+                             name_len - ACCESS_MIB_LENGTH,
+                             (u_char **) & newGroupName, &groupNameLen,
+                             (u_char **) & newContextPrefix, &contextPrefixLen,
+                             &model, &level)) {
+            return SNMP_ERR_INCONSISTENTNAME;
+        }
+
+        aptr = vacm_getAccessEntry(newGroupName, newContextPrefix, model, level);
 
         if (aptr) {
             if (long_ret == RS_DESTROY) {
@@ -1220,21 +1222,22 @@ write_vacmAccessStatus(int action,
         free(newContextPrefix);
     } else if (action == UNDO) {
         if (long_ret == RS_CREATEANDGO || long_ret == RS_CREATEANDWAIT) {
-            access_parse_oid(&name[ACCESS_MIB_LENGTH],
-                             name_len - ACCESS_MIB_LENGTH,
-                             (u_char **) & newGroupName, &groupNameLen,
-                             (u_char **) & newContextPrefix,
-                             &contextPrefixLen, &model, &level);
-            aptr =
-                vacm_getAccessEntry(newGroupName, newContextPrefix, model,
-                                    level);
+            if (access_parse_oid(&name[ACCESS_MIB_LENGTH],
+                                 name_len - ACCESS_MIB_LENGTH,
+                                 (u_char **) & newGroupName, &groupNameLen,
+                                 (u_char **) & newContextPrefix, &contextPrefixLen,
+                                 &model, &level)) {
+                return SNMP_ERR_INCONSISTENTNAME;
+            }
+
+            aptr = vacm_getAccessEntry(newGroupName, newContextPrefix, model, level);
             if (aptr != NULL) {
                 vacm_destroyAccessEntry(newGroupName, newContextPrefix,
                                         model, level);
             }
+            free(newGroupName);
+            free(newContextPrefix);
         }
-        free(newGroupName);
-        free(newContextPrefix);
     }
 
     return SNMP_ERR_NOERROR;
