@@ -211,6 +211,7 @@ snmpNotifyFilter_storage_add(const u_char *profileName, size_t profileName_len,
     if (NULL == data)
         return NULL;
 
+    data->snmpNotifyFilterMask_len = filterMask_len;
     memcpy(data->snmpNotifyFilterMask, filterMask, filterMask_len);
 
     data->snmpNotifyFilterType = filterType;
@@ -258,8 +259,8 @@ snmpNotifyFilter_vacm_view_subtree(const char *profile)
     /*
      * allocate temporary storage
      */
-    tmp = (struct vacm_viewEntry*)calloc(sizeof(struct vacm_viewEntry),
-                                         s->size + 1);
+    tmp = (struct vacm_viewEntry*)calloc(s->size + 1,
+                                         sizeof(struct vacm_viewEntry));
     if (NULL == tmp) {
         free(s->array);
         free(s);
