@@ -9,17 +9,16 @@
 #include "hardware/sensors/hw_sensors.h"
 #include "ucd-snmp/lmsensorsMib.h"
 
-netsnmp_container *sensorContainer = NULL;
+struct reg_and_table {
+    netsnmp_handler_registration *reg;
+    netsnmp_table_registration_info *table;
+};
 
-static void initialize_lmSensorsTable(const char *tableName,
-                                      const oid *tableOID,
-                                      netsnmp_container_op *filter,
-                                      int mult);
-
-static int _sensor_filter_temp( netsnmp_container *c, const void *v );
-static int _sensor_filter_fan(  netsnmp_container *c, const void *v );
-static int _sensor_filter_volt( netsnmp_container *c, const void *v );
-static int _sensor_filter_misc( netsnmp_container *c, const void *v );
+static netsnmp_container *sensorContainer;
+static struct reg_and_table temp_reg;
+static struct reg_and_table fan_reg;
+static struct reg_and_table volt_reg;
+static struct reg_and_table misc_reg;
 
 static const oid lmTempSensorsTable_oid[]   = {1,3,6,1,4,1,2021,13,16,2};
 static const oid lmFanSensorsTable_oid[]    = {1,3,6,1,4,1,2021,13,16,3};
@@ -29,31 +28,10 @@ static const oid lmMiscSensorsTable_oid[]   = {1,3,6,1,4,1,2021,13,16,5};
 const size_t lmSensorsTables_oid_len = OID_LENGTH(lmMiscSensorsTable_oid);
 
 
-/* Initialise the LM Sensors MIB module */
-void
-init_lmsensorsMib(void)
-{
-    DEBUGMSGTL(("ucd-snmp/lmsensorsMib","Initializing LM-SENSORS-MIB tables\n"));
-
-    /* 
-     * Initialise the four LM-SENSORS-MIB tables
-     *
-     * They are almost identical, so we can use the same registration code.
-     */
-    initialize_lmSensorsTable( "lmTempSensorsTable", lmTempSensorsTable_oid,
-                                _sensor_filter_temp, 1000 );  /* MIB asks for mC */
-    initialize_lmSensorsTable( "lmFanSensorsTable",  lmFanSensorsTable_oid,
-                                _sensor_filter_fan,  1);
-    initialize_lmSensorsTable( "lmVoltSensorsTable", lmVoltSensorsTable_oid,
-                                _sensor_filter_volt, 1000 );  /* MIB asks for mV */
-    initialize_lmSensorsTable( "lmMiscSensorsTable", lmMiscSensorsTable_oid,
-                                _sensor_filter_misc, 1 );
-}
-
 /*
  * Common initialisation code, used for setting up all four tables
  */
-void
+static struct reg_and_table
 initialize_lmSensorsTable(const char *tableName, const oid *tableOID,
                           netsnmp_container_op *filter, int mult )
 {
@@ -61,6 +39,9 @@ initialize_lmSensorsTable(const char *tableName, const oid *tableOID,
     netsnmp_table_registration_info *table_info;
     netsnmp_cache     *cache;
     netsnmp_container *container;
+    struct reg_and_table res;
+
+    memset(&res, 0, sizeof(res));
 
     /*
      * Ensure the HAL sensors module has been initialised,
@@ -93,11 +74,11 @@ initialize_lmSensorsTable(const char *tableName, const oid *tableOID,
     table_info = SNMP_MALLOC_TYPEDEF( netsnmp_table_registration_info );
     netsnmp_table_helper_add_indexes(table_info, ASN_INTEGER, 0);
     table_info->min_column = COLUMN_LMSENSORS_INDEX;
-    table_info->max_column = COLUMN_LMSENSORS_VALUE;
+    table_info->max_column = COLUMN_LMSENSORS_SIGNED;
     if (netsnmp_container_table_register(reg, table_info, container, 0) !=
         SNMPERR_SUCCESS) {
         snmp_log(LOG_ERR, "Failed to register the sensors container table\n");
-        return;
+        return res;
     }
 
     /*
@@ -111,6 +92,9 @@ initialize_lmSensorsTable(const char *tableName, const oid *tableOID,
                                             "table_container");
     }
 
+    res.reg = reg;
+    res.table = table_info;
+    return res;
 }
 
 
@@ -119,26 +103,30 @@ initialize_lmSensorsTable(const char *tableName, const oid *tableOID,
  *
  *  Used to ensure that sensor entries appear in the appropriate table.
  */
-int _sensor_filter_temp( netsnmp_container *c, const void *v ) {
+static int _sensor_filter_temp( netsnmp_container *c, const void *v )
+{
     const netsnmp_sensor_info *sp = (const netsnmp_sensor_info *)v;
     /* Only matches temperature sensors */
     return (( sp->type == NETSNMP_SENSOR_TYPE_TEMPERATURE ) ? 0 : 1 );
 }
 
-int _sensor_filter_fan( netsnmp_container *c, const void *v ) {
+static int _sensor_filter_fan( netsnmp_container *c, const void *v )
+{
     const netsnmp_sensor_info *sp = (const netsnmp_sensor_info *)v;
     /* Only matches fan sensors */
     return (( sp->type == NETSNMP_SENSOR_TYPE_RPM ) ? 0 : 1 );
 }
 
-int _sensor_filter_volt( netsnmp_container *c, const void *v ) {
+static int _sensor_filter_volt( netsnmp_container *c, const void *v )
+{
     const netsnmp_sensor_info *sp = (const netsnmp_sensor_info *)v;
     /* Only matches voltage sensors (AC or DC) */
     return ((( sp->type == NETSNMP_SENSOR_TYPE_VOLTAGE_DC ) ||
              ( sp->type == NETSNMP_SENSOR_TYPE_VOLTAGE_AC )) ? 0 : 1 );
 }
 
-int _sensor_filter_misc( netsnmp_container *c, const void *v ) {
+static int _sensor_filter_misc( netsnmp_container *c, const void *v )
+{
     const netsnmp_sensor_info *sp = (const netsnmp_sensor_info *)v;
     /* Matches everything except temperature, fan or voltage sensors */
     return ((( sp->type == NETSNMP_SENSOR_TYPE_TEMPERATURE ) ||
@@ -147,6 +135,41 @@ int _sensor_filter_misc( netsnmp_container *c, const void *v ) {
              ( sp->type == NETSNMP_SENSOR_TYPE_VOLTAGE_AC  )) ? 1 : 0 );
 }
 
+/* Initialize the LM Sensors MIB module */
+void
+init_lmsensorsMib(void)
+{
+    DEBUGMSGTL(("ucd-snmp/lmsensorsMib","Initializing LM-SENSORS-MIB tables\n"));
+
+    /*
+     * Initialize the four LM-SENSORS-MIB tables
+     *
+     * They are almost identical, so we can use the same registration code.
+     */
+    temp_reg = initialize_lmSensorsTable("lmTempSensorsTable",
+                   lmTempSensorsTable_oid, _sensor_filter_temp,
+                   1000);  /* MIB asks for mC */
+    fan_reg = initialize_lmSensorsTable("lmFanSensorsTable",
+                   lmFanSensorsTable_oid, _sensor_filter_fan,  1);
+    volt_reg = initialize_lmSensorsTable("lmVoltSensorsTable",
+                   lmVoltSensorsTable_oid, _sensor_filter_volt,
+                   1000);  /* MIB asks for mV */
+    misc_reg = initialize_lmSensorsTable("lmMiscSensorsTable",
+                   lmMiscSensorsTable_oid, _sensor_filter_misc, 1);
+}
+
+void
+shutdown_lmsensorsMib(void)
+{
+    netsnmp_table_registration_info_free(misc_reg.table);
+    netsnmp_unregister_table(misc_reg.reg);
+    netsnmp_table_registration_info_free(volt_reg.table);
+    netsnmp_unregister_table(volt_reg.reg);
+    netsnmp_table_registration_info_free(fan_reg.table);
+    netsnmp_unregister_table(fan_reg.reg);
+    netsnmp_table_registration_info_free(temp_reg.table);
+    netsnmp_unregister_table(temp_reg.reg);
+}
 
 /*
  * Handle requests for any of the four lmXxxxSensorsTables 
@@ -203,6 +226,15 @@ lmSensorsTables_handler(
                 snmp_set_var_typed_integer( request->requestvb, ASN_GAUGE,
                                             (int)(mult*sensor_info->value));
                 break;
+            case COLUMN_LMSENSORS_SIGNED:
+		/* Only avalable for temperature table */
+	        if (reginfo->rootoid[9] != 2)
+		    netsnmp_set_request_error(reqinfo, request, SNMP_NOSUCHOBJECT);
+		else
+                    /* Multiply the value by the appropriate scaling factor for this table */
+                    snmp_set_var_typed_integer( request->requestvb, ASN_INTEGER,
+                                                (int)(mult*sensor_info->value));
+                break;
             default:
                 netsnmp_set_request_error(reqinfo, request,
                                           SNMP_NOSUCHOBJECT);
