@@ -1,11 +1,12 @@
 #ifndef LM_SENSORS_MIB_H
 #define LM_SENSORS_MIB_H
 
-config_require(hardware/sensors)
-config_add_mib(LM-SENSORS-MIB)
+config_require(hardware/sensors);
+config_add_mib(LM-SENSORS-MIB);
 
 /* function declarations */
 void init_lmsensorsMib(void);
+void shutdown_lmsensorsMib(void);
 
 /*
  * Handler and Column definitions for lmXxxxSensorsTable
@@ -19,5 +20,6 @@ Netsnmp_Node_Handler lmSensorsTables_handler;
 #define COLUMN_LMSENSORS_INDEX		1
 #define COLUMN_LMSENSORS_DEVICE		2
 #define COLUMN_LMSENSORS_VALUE		3
+#define COLUMN_LMSENSORS_SIGNED		4
 
 #endif /* LM_SENSORS_MIB_H */
