@@ -5,7 +5,7 @@
 #ifndef _MIBGROUP_MEMORY_AIX4_H
 #define _MIBGROUP_MEMORY_AIX4_H
 
-config_require(util_funcs/header_generic)
+config_require(util_funcs/header_generic);
 
 #include "mibdefs.h"
 
