@@ -31,45 +31,45 @@ SOFTWARE.
 
 #include <net-snmp/net-snmp-config.h>
 
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
 #endif
 #include <sys/types.h>
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
 #include <stdio.h>
 #include <ctype.h>
-#if TIME_WITH_SYS_TIME
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# if HAVE_SYS_TIME_H
+# ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # else
 #  include <time.h>
 # endif
 #endif
-#if HAVE_SYS_SELECT_H
+#ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
-#if HAVE_NETDB_H
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
-#if HAVE_ARPA_INET_H
+#ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
-#if HAVE_NCURSES_CURSES_H
+#ifdef HAVE_NCURSES_CURSES_H
 #include <ncurses/curses.h>
-#elif HAVE_CURSES_H
+#elif defined(HAVE_CURSES_H)
 #include <curses.h>
 #endif
 #include <signal.h>
@@ -190,12 +190,17 @@ add(netsnmp_pdu *pdu, const char *mibnodename,
         snmp_perror(mibnodename);
         fprintf(stderr, "couldn't find mib node %s, giving up\n",
                 mibnodename);
-#if HAVE_CURSES_H
+#ifdef HAVE_CURSES_H
         endwin();
 #endif
         exit(1);
     }
 
+    if (base_length + indexlen > sizeof(base) / sizeof(base[0])) {
+        fprintf(stderr, "internal error for %s, giving up\n", mibnodename);
+        exit(1);
+    }
+
     if (index && indexlen) {
         memcpy(&(base[base_length]), index, indexlen * sizeof(oid));
         base_length += indexlen;
@@ -224,7 +229,7 @@ collect_procs(netsnmp_session *ss, netsnmp_pdu *pdu,
         status = snmp_synch_response(ss, pdu, &response);
         if (status != STAT_SUCCESS || !response) {
             snmp_sess_perror(progname, ss);
-#if HAVE_CURSES_H
+#ifdef HAVE_CURSES_H
             endwin();
 #endif
             exit(1);
@@ -232,7 +237,7 @@ collect_procs(netsnmp_session *ss, netsnmp_pdu *pdu,
         if (response->errstat != SNMP_ERR_NOERROR) {
             fprintf(stderr, "%s: Error in packet: %s\n", progname,
                     snmp_errstring(response->errstat));
-#if HAVE_CURSES_H
+#ifdef HAVE_CURSES_H
             endwin();
 #endif
             exit(1);
@@ -317,7 +322,7 @@ collect_perf(netsnmp_session *ss, struct hrSWRunTable **fproc)
         status = snmp_synch_response(ss, pdu, &response);
         if (status != STAT_SUCCESS || !response) {
             snmp_sess_perror(progname, ss);
-#if HAVE_CURSES_H
+#ifdef HAVE_CURSES_H
             endwin();
 #endif
             exit(1);
@@ -332,44 +337,52 @@ collect_perf(netsnmp_session *ss, struct hrSWRunTable **fproc)
         proc.hrSWRunIndex = vlp->name[base_length];
 
         vlp2 = response->variables;
-        if (vlp2->type == SNMP_NOSUCHINSTANCE) goto next;
+        if (vlp2->type == SNMP_NOSUCHINSTANCE ||
+            vlp2->type == SNMP_NOSUCHOBJECT) goto next;
         len = vlp2->val_len;
         proc.hrSWRunName = malloc(len+1);
         memcpy(proc.hrSWRunName, vlp2->val.string, len);
         proc.hrSWRunName[len] = '\0';
 
         vlp2 = vlp2->next_variable;
-        if (vlp2->type == SNMP_NOSUCHINSTANCE) goto next;
+        if (vlp2->type == SNMP_NOSUCHINSTANCE ||
+            vlp2->type == SNMP_NOSUCHOBJECT) goto next;
         proc.hrSWRunID = *vlp2->val.integer;
 
         vlp2 = vlp2->next_variable;
-        if (vlp2->type == SNMP_NOSUCHINSTANCE) goto next;
+        if (vlp2->type == SNMP_NOSUCHINSTANCE ||
+            vlp2->type == SNMP_NOSUCHOBJECT) goto next;
         len = vlp2->val_len;
         proc.hrSWRunPath = malloc(len+1);
         memcpy(proc.hrSWRunPath, vlp2->val.string, len);
         proc.hrSWRunPath[len] = '\0';
 
         vlp2 = vlp2->next_variable;
-        if (vlp2->type == SNMP_NOSUCHINSTANCE) goto next;
+        if (vlp2->type == SNMP_NOSUCHINSTANCE ||
+            vlp2->type == SNMP_NOSUCHOBJECT) goto next;
         len = vlp2->val_len;
         proc.hrSWRunParameters = malloc(len+1);
         memcpy(proc.hrSWRunParameters, vlp2->val.string, len);
         proc.hrSWRunParameters[len] = '\0';
 
         vlp2 = vlp2->next_variable;
-        if (vlp2->type == SNMP_NOSUCHINSTANCE) goto next;
+        if (vlp2->type == SNMP_NOSUCHINSTANCE ||
+            vlp2->type == SNMP_NOSUCHOBJECT) goto next;
         proc.hrSWRunType = *vlp2->val.integer;
 
         vlp2 = vlp2->next_variable;
-        if (vlp2->type == SNMP_NOSUCHINSTANCE) goto next;
+        if (vlp2->type == SNMP_NOSUCHINSTANCE ||
+            vlp2->type == SNMP_NOSUCHOBJECT) goto next;
         proc.hrSWRunStatus = *vlp2->val.integer;
 
         vlp2 = vlp2->next_variable;
-        if (vlp2->type == SNMP_NOSUCHINSTANCE) goto next;
+        if (vlp2->type == SNMP_NOSUCHINSTANCE ||
+            vlp2->type == SNMP_NOSUCHOBJECT) goto next;
         proc.hrSWRunPerfCPU = *vlp2->val.integer;
 
         vlp2 = vlp2->next_variable;
-        if (vlp2->type == SNMP_NOSUCHINSTANCE) goto next;
+        if (vlp2->type == SNMP_NOSUCHINSTANCE ||
+            vlp2->type == SNMP_NOSUCHOBJECT) goto next;
         proc.hrSWRunPerfMem = *vlp2->val.integer;
 
         count++;
@@ -717,13 +730,15 @@ snmpps(int argc, char *argv[])
         pinx++;
     }
 
+    free_perf(procs, count);
     snmp_close(ss);
+    netsnmp_cleanup_session(&session);
     SOCK_CLEANUP;
     return 0;
 }
 
 
-#if HAVE_CURSES_H
+#ifdef HAVE_CURSES_H
 static void endtop(int sig)
 {
     endwin();
@@ -865,7 +880,10 @@ int snmptop(int argc, char **argv)
 
         clock = time(NULL);
         ptm = localtime(&clock);
-        strftime(timestr, sizeof(timestr), "%H:%M:%S", ptm);
+        if (ptm)
+            strftime(timestr, sizeof(timestr), "%H:%M:%S", ptm);
+        else
+            snprintf(timestr, sizeof(timestr), "(unknown)");
 
         clear();
         move(0, 0);
@@ -975,7 +993,9 @@ int snmptop(int argc, char **argv)
     }
     endwin();
 
+    free_perf(oproc, ocount);
     snmp_close(ss);
+    netsnmp_cleanup_session(&session);
     SOCK_CLEANUP;
     return 0;
 }
