@@ -55,9 +55,6 @@ typedef struct container_type_s {
    netsnmp_container_compare  *compare;
 } container_type;
 
-netsnmp_factory *
-netsnmp_container_get_factory(const char *type);
-
 /*------------------------------------------------------------------
  */
 static void 
@@ -138,7 +135,7 @@ netsnmp_container_free_list(void)
     /*
      * free memory used by each factory entry
      */
-    CONTAINER_FOR_EACH(containers, ((netsnmp_container_obj_func *)_factory_free), NULL);
+    CONTAINER_FOR_EACH(containers, _factory_free, NULL);
 
     /*
      * free factory container
@@ -776,3 +773,8 @@ netsnmp_container_simple_free(void *data, void *context)
                 data, context));
     free(data); /* SNMP_FREE wasted on param */
 }
+
+int netsnmp_str_compare(const void *left, const void *right)
+{
+    return strcmp(left, right);
+}
