@@ -35,7 +35,11 @@ struct netsnmp_ep_str {
     char     port[6];
 };
 
+struct netsnmp_transport_s;
+
 int netsnmp_parse_ep_str(struct netsnmp_ep_str *ep_str, const char *endpoint);
 int netsnmp_bindtodevice(int fd, const char *iface);
+int netsnmp_ipbase_session_init(struct netsnmp_transport_s *transport,
+                                struct snmp_session *sess);
 
 #endif /* _SNMPIPBASEDOMAIN_H_ */
